summaryrefslogtreecommitdiffstats
path: root/kspread/plugins/calculator/kcalc.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:31 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:31 -0600
commitc9cb4f487428aad5d8cda5e3a4b9ad87390d7e54 (patch)
tree1ee1912ac4bb966475f0db0f2a78678661b4b4a5 /kspread/plugins/calculator/kcalc.cpp
parent94844816550ad672ccfcdc25659c625546239998 (diff)
downloadkoffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.tar.gz
koffice-c9cb4f487428aad5d8cda5e3a4b9ad87390d7e54.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 94844816550ad672ccfcdc25659c625546239998.
Diffstat (limited to 'kspread/plugins/calculator/kcalc.cpp')
-rw-r--r--kspread/plugins/calculator/kcalc.cpp48
1 files changed, 24 insertions, 24 deletions
diff --git a/kspread/plugins/calculator/kcalc.cpp b/kspread/plugins/calculator/kcalc.cpp
index b15f844c..4c80e7b4 100644
--- a/kspread/plugins/calculator/kcalc.cpp
+++ b/kspread/plugins/calculator/kcalc.cpp
@@ -26,7 +26,7 @@
#include "version.h"
#include <klocale.h>
#include <knotifyclient.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqobjectlist.h>
#include <tqpushbutton.h>
#include <kapplication.h>
@@ -80,7 +80,7 @@ TQtCalculator :: TQtCalculator( Calculator *_corba, TQWidget *parent, const char
// Create the display
calc_display = new DLabel( this, "display" );
calc_display->setFrameStyle( TQFrame::WinPanel | TQFrame::Sunken );
- calc_display->setAlignment( AlignRight|AlignVCenter );
+ calc_display->tqsetAlignment( AlignRight|AlignVCenter );
calc_display->setFocus();
calc_display->setFocusPolicy( TQ_StrongFocus );
@@ -89,18 +89,18 @@ TQtCalculator :: TQtCalculator( Calculator *_corba, TQWidget *parent, const char
statusINVLabel = new TQLabel( this, "INV" );
Q_CHECK_PTR( statusINVLabel );
statusINVLabel->setFrameStyle( TQFrame::Panel | TQFrame::Sunken );
- statusINVLabel->setAlignment( AlignCenter );
+ statusINVLabel->tqsetAlignment( AlignCenter );
statusINVLabel->setText("NORM");
statusHYPLabel = new TQLabel( this, "HYP" );
Q_CHECK_PTR( statusHYPLabel );
statusHYPLabel->setFrameStyle( TQFrame::Panel | TQFrame::Sunken );
- statusHYPLabel->setAlignment( AlignCenter );
+ statusHYPLabel->tqsetAlignment( AlignCenter );
statusERRORLabel = new TQLabel( this, "ERROR" );
Q_CHECK_PTR( statusERRORLabel );
statusERRORLabel->setFrameStyle( TQFrame::Panel | TQFrame::Sunken );
- statusERRORLabel->setAlignment( AlignLeft|AlignVCenter );
+ statusERRORLabel->tqsetAlignment( AlignLeft|AlignVCenter );
// create angle button group
@@ -390,12 +390,12 @@ TQtCalculator :: TQtCalculator( Calculator *_corba, TQWidget *parent, const char
mainLayout->addLayout(btnLayout);
mainLayout->addLayout(statusLayout);
- // button layout
+ // button tqlayout
btnLayout->addWidget(mSmallPage,0,AlignTop);
btnLayout->addSpacing(mInternalSpacing);
btnLayout->addWidget(mLargePage,0,AlignTop);
// small button layout
smallBtnLayout->addWidget(pbhyp, 0, 0);
smallBtnLayout->addWidget(pbinv, 0, 1);
smallBtnLayout->addWidget(pbA, 0, 2);
@@ -427,7 +427,7 @@ TQtCalculator :: TQtCalculator( Calculator *_corba, TQWidget *parent, const char
smallBtnLayout->setRowStretch(4, 0);
smallBtnLayout->setRowStretch(5, 0);
// large button layout
largeBtnLayout->addWidget(pbEE, 0, 0);
largeBtnLayout->addWidget(pbMR, 0, 1);
largeBtnLayout->addWidget(pbMplusminus, 0, 2);
@@ -472,11 +472,11 @@ TQtCalculator :: TQtCalculator( Calculator *_corba, TQWidget *parent, const char
topLayout->addWidget(calc_display, 10);
- // radiobutton layout
+ // radiobutton tqlayout
radioLayout->addWidget(base_group);
radioLayout->addWidget(angle_group);
- // status layout
+ // status tqlayout
statusLayout->addWidget(statusINVLabel);
statusLayout->addWidget(statusHYPLabel);
statusLayout->addWidget(statusERRORLabel, 10);
@@ -578,7 +578,7 @@ void TQtCalculator::updateGeometry()
s.setWidth(mSmallPage->fontMetrics().width("MMM"));
s.setHeight(mSmallPage->fontMetrics().lineSpacing());
- l = (TQObjectList*)mSmallPage->children(); // silence please
+ l = (TQObjectList*)mSmallPage->tqchildren(); // silence please
for(uint i=0; i < l->count(); i++)
{
@@ -586,20 +586,20 @@ void TQtCalculator::updateGeometry()
if( o->isWidgetType() )
{
margin = TQApplication::style().
- pixelMetric(TQStyle::PM_ButtonMargin, ((TQWidget *)o))*2;
+ tqpixelMetric(TQStyle::PM_ButtonMargin, ((TQWidget *)o))*2;
((TQWidget*)o)->setMinimumSize(s.width()+margin, s.height()+margin);
((TQWidget*)o)->installEventFilter( this );
((TQWidget*)o)->setAcceptDrops(true);
}
}
- l = (TQObjectList*)mLargePage->children(); // silence please
+ l = (TQObjectList*)mLargePage->tqchildren(); // silence please
- int h1 = pbF->minimumSize().height();
+ int h1 = pbF->tqminimumSize().height();
int h2 = (int)((((float)h1 + 4.0) / 5.0));
s.setWidth(mLargePage->fontMetrics().width("MMM") +
TQApplication::style().
- pixelMetric(TQStyle::PM_ButtonMargin, pbF)*2);
+ tqpixelMetric(TQStyle::PM_ButtonMargin, pbF)*2);
s.setHeight(h1 + h2);
for(uint i = 0; i < l->count(); i++)
@@ -621,7 +621,7 @@ void TQtCalculator::updateGeometry()
statusINVLabel->setMinimumWidth(s.width());
statusHYPLabel->setMinimumWidth(s.width());
- //setFixedSize(minimumSize());
+ //setFixedSize(tqminimumSize());
}
void TQtCalculator::exit()
@@ -1465,9 +1465,9 @@ void TQtCalculator::configclicked(){
lay1->setSpacing( KDialog::spacingHint() );
TQGroupBox *box = new TQGroupBox(0,Qt::Vertical,about,"box");
- box->layout()->setSpacing(KDialog::spacingHint());
- box->layout()->setMargin(KDialog::marginHint());
- TQGridLayout *grid1 = new TQGridLayout(box->layout(),2,2);
+ box->tqlayout()->setSpacing(KDialog::spacingHint());
+ box->tqlayout()->setMargin(KDialog::marginHint());
+ TQGridLayout *grid1 = new TQGridLayout(box->tqlayout(),2,2);
TQLabel *label = new TQLabel(box,"label");
TQLabel *label2 = new TQLabel(box,"label2");
@@ -1494,10 +1494,10 @@ void TQtCalculator::configclicked(){
"enabled. See the README for details.");
#endif
- label->setAlignment(AlignLeft|WordBreak|ExpandTabs);
+ label->tqsetAlignment(AlignLeft|WordBreak|ExpandTabs);
label->setText(labelstring);
- label2->setAlignment(AlignLeft|WordBreak|ExpandTabs);
+ label2->tqsetAlignment(AlignLeft|WordBreak|ExpandTabs);
label2->setText(labelstring2);
// HACK
@@ -1540,7 +1540,7 @@ void TQtCalculator::configclicked(){
set_precision();
set_style();
updateGeometry();
- resize(minimumSize());
+ resize(tqminimumSize());
}
delete configdlg;
}
@@ -1628,7 +1628,7 @@ void TQtCalculator::display_selected(){
if(calc_display->isLit()){
- TQClipboard *cb = TQApplication::clipboard();
+ TQClipboard *cb = TQApplication::tqclipboard();
cb->setText(calc_display->text());
selection_timer->start(100);
@@ -1643,7 +1643,7 @@ void TQtCalculator::display_selected(){
}
else{
- TQClipboard *cb = TQApplication::clipboard();
+ TQClipboard *cb = TQApplication::tqclipboard();
CALCAMNT result;
result = (CALCAMNT) cb->text().toDouble();
@@ -390,12 +390,12 @@ TQtCalculator :: TQtCalculator( Calculator *_corba, TQWidget *parent, const char
btnLayout->addSpacing(mInternalSpacing);
btnLayout->addWidget(mLargePage,0,AlignTop);
- // small button layout
+ // small button tqlayout
smallBtnLayout->addWidget(pbhyp, 0, 0);
smallBtnLayout->addWidget(pbinv, 0, 1);
@@ -427,7 +427,7 @@ TQtCalculator :: TQtCalculator( Calculator *_corba, TQWidget *parent, const char
smallBtnLayout->setRowStretch(4, 0);
smallBtnLayout->setRowStretch(5, 0);
- // large button layout
+ // large button tqlayout
largeBtnLayout->addWidget(pbEE, 0, 0);
largeBtnLayout->addWidget(pbMR, 0, 1);